#
# spec file for package sblim-cmpi-sysfs
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sblim-cmpi-sysfs
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  sblim-cmpi-base-devel
BuildRequires:  sblim-indication_helper-devel
BuildRequires:  sblim-sfcb
BuildRequires:  sblim-testsuite
%if 0%{?rhel_version} == 0 && 0%{?centos_version} == 0
BuildRequires:  openslp-devel
%endif
Url:            http://sblim.wiki.sourceforge.net/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        SBLIM Linux Sysfs Instrumentation for CMPI
License:        EPL-1.0
Group:          System/Management
Version:        1.2.0
Release:        4.3
Requires:       cim-schema
Requires:       cim-server
Requires:       sblim-cmpi-base >= 1.2.3
Source0:        http://prdownloads.sourceforge.net/sblim/sblim-cmpi-sysfs-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM sblim-cmpi-sysfs-enumerate-symlinks.patch bnc927344 sf#1648 pwieczorkiewicz@suse.de -- Enumerate also symlink
Patch0:         sblim-cmpi-sysfs-enumerate-symlinks.patch
#!BuildIgnore:  tog-pegasus

%description
This package provides SBLIM instrumentation to expose the kernel
devices accessible via sysfs, which is a virtual filesystem in Linux
kernel versions 2.5+ that provides a tree of system devices. The sysfs
filesystem is mounted under /sys and the various subdirectories of /sys
represent the different classes of devices currently registered on the
machine.



Authors:
--------
    SBLIM Project

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1 

%build
%configure --disable-static
%{__make}

%install
%if 0%{?suse_version}
%makeinstall docdir=%{_docdir}/%{name}
%else
make install DESTDIR=%{buildroot} docdir=%{_docdir}/%{name}-%{version}
%endif
rm %buildroot%_libdir/cmpi/*.la
rm %buildroot%_libdir/*.la

%clean
%{__rm} -rf $RPM_BUILD_ROOT
%define PEGASUS_MOF CIM_UnixLocalFileSystem

%post
# compile MOF
/sbin/ldconfig
# Register Schema and Provider - this is higly provider specific  
# tog-pegasus needs some schemes registered first  
if [ -x /usr/bin/peg-loadmof.sh ]; then  
    peg-loadmof.sh -n root/cimv2 /usr/share/mof/cim-current/*/%{PEGASUS_MOF}.mof  
    rctog-pegasus try-restart  
fi  
# and then following script can handle registration for various providers  
d=%{_datadir}/%{name}
$d/provider-register.sh -r $d/*.registration -m $d/*.mof

%preun
if [ "$1" = "0" ]; then
  d=%{_datadir}/%{name}
  $d/provider-register.sh -d -r $d/*.registration -m $d/*.mof
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
# skip-check-libtool-deps
%{_libdir}/cmpi/*.so
%{_libdir}/*.so
%{_datadir}/sblim-testsuite
%{_datadir}/%{name}
%if 0%{?suse_version}
%doc %{_docdir}/%{name}
%else
%doc %{_docdir}/%{name}-%{version}
%endif

%changelog
* Tue Apr 28 2015 pwieczorkiewicz@suse.com
- sblim-cmpi-sysfs-enumerate-symlinks.patch:
  Enumerate devices which are represetned as symlinks in /sys/block
  (bsc#927344, sf#1648)
* Tue Apr  3 2012 kkaempf@suse.com
- Fix CentOS build
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Sep 14 2010 kkaempf@novell.com
- Fix RH/Fedora build
* Thu Oct  1 2009 mhrusecky@suse.cz
- updated to 1.2.0
  - updated URL for CPL
  - migrate provider licenses to EPL
* Tue Sep  8 2009 mhrusecky@suse.cz
- fixed registration with tog-pegasus
* Tue May 12 2009 mhrusecky@suse.cz
- ignoring tog-pegasus during the build
* Thu Jan  8 2009 mhrusecky@suse.cz
- registering everything in one step to prevent unnecessary sfcb
  restarts
* Fri Sep 12 2008 mmarek@suse.cz
- switch to sfcb
* Thu Nov  1 2007 mmarek@suse.cz
- updated to 1.1.9
  fixed upstream bugs:
  * 1199129 Providers won't compile with CMPI 1.0
  * 1430899 Loop in sysfs provider on newer /sys
  * 1532575 cmpi-sysfs: seg fault if file contains hex data
  * 1533889 cmpi-sysfs: find options in the wrong order
- removed static libs
* Tue Jan 16 2007 mrueckert@suse.de
- added sblim-cmpi-sysfs-1.1.8_Linux_SysfsAttributeUtil.c.makeinstance.patch:
  check for nonprintable data and return NULL in case (#192299)
* Tue Mar  7 2006 mrueckert@suse.de
- added sblim-cmpi-sysfs-1.1.7_sysfs_no_follow.patch
  sysfs contains cyclic symlinks. the provider uses find(1) to
  traversal the tree. the patch fixes the find call so it wont
  loop infinitely anymore. (#154863)
* Wed Mar  1 2006 mrueckert@suse.de
- update to 1.1.8 [#144214]
- dropped all patches as the build system has changed
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 13 2005 mrueckert@suse.de
- update to 1.1.7
- build with openwbem
- build with optflags
- use new loadmof/rmmof syntax
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Thu May 20 2004 nashif@suse.de
- fix #40890: provider fails to read file/dir names that contain
  spaces
- V. 1.1.3
* Wed May 12 2004 nashif@suse.de
- Do not De-register when updating package
* Mon May 10 2004 nashif@suse.de
- Dereigster providers when uninstalling (#39667)
- test scripts incorrectly check file read/write permission (#40262)
* Fri Apr 30 2004 nashif@suse.de
- Update to version 1.1.1
- fixes bug #39032: util libs installed in wrong directory
* Wed Apr 14 2004 nashif@suse.de
- Added PreReq for loadmof.sh
* Wed Apr  7 2004 nashif@suse.de
- Initial version
